==> speech-sdk-0.5.8-sources.jar: com/segway/robot/sdk/voice/CheckUtil.java <==
package com.segway.robot.sdk.voice;

import com.segway.robot.sdk.base.log.Logger;
import com.segway.robot.sdk.voice.grammar.Slot;

import java.util.List;

class CheckUtil {

    private static final String TAG = CheckUtil.class.getSimpleName();

    public static boolean isEnChar(String chars) {
        StringBuilder illegalChars = new StringBuilder();
        int length = chars.length();
        for (int i = 0; i < length; i++) {
            char item = chars.charAt(i);
            if (!((('a' <= item) && ('z' >= item)) || (('A' <= item) && ('Z' >= item)) || (' ' == item))) {
                illegalChars.append("(").append(item).append(")");
            }
        }
        if (illegalChars.length() != 0) {
            Logger.e(TAG, "illegal char(chars): " + illegalChars.toString());
            return false;
        }
        return true;
    }

    public static boolean isCnChar(String chars) {
        StringBuilder illegalChars = new StringBuilder();
        int length = chars.length();
        for (int i = 0; i < length; i++) {
            char item = chars.charAt(i);
            if (!((item >= 0x4e00) && (item <= 0x9fbb))) {
                illegalChars.append("(").append(item).append(")");
            }
        }
        if (illegalChars.length() != 0) {
            Logger.e(TAG, "illegal char(chars): " + illegalChars.toString());
            return false;
        }
        return true;
    }

    public static boolean isEnSlot(Slot slot) {
        if (slot == null) {
            throw new IllegalArgumentException("The slot can not be null!");
        }
        List<String> wordList = slot.getWordList();
        if (wordList.isEmpty()) {
            throw new IllegalArgumentException("The slot has no word!");
        }
        for (String word : wordList) {
            boolean en = isEnChar(word);
            if (!en) {
                return false;
            }
        }
        return true;
    }

    public static boolean isCnSlot(Slot slot) {
        if (slot == null) {
            throw new IllegalArgumentException("The slot can not be null");
        }
        List<String> wordList = slot.getWordList();
        if (wordList.isEmpty()) {
            throw new IllegalArgumentException("The slot has no word");
        }
        for (String word : wordList) {
            boolean en = isCnChar(word);
            if (!en) {
                return false;
            }
        }
        return true;
    }
}

==> speech-sdk-0.5.32-sources.jar: com/segway/robot/sdk/voice/CheckUtil.java <==
package com.segway.robot.sdk.voice;

import com.segway.robot.sdk.base.log.Logger;
import com.segway.robot.sdk.voice.grammar.Slot;

import java.util.List;

class CheckUtil {

    private static final String TAG = CheckUtil.class.getSimpleName();

    public static boolean isEnChar(String chars) {
        StringBuilder illegalChars = new StringBuilder();
        int length = chars.length();
        for (int i = 0; i < length; i++) {
            char item = chars.charAt(i);
            if (!((('a' <= item) && ('z' >= item)) || (('A' <= item) && ('Z' >= item)) || (' ' == item)
            || ('-' == item) || ('\'' == item))) {
                illegalChars.append("(").append(item).append(")");
            }
        }
        if (illegalChars.length() != 0) {
            Logger.e(TAG, "Illegal char(chars): " + illegalChars.toString());
            return false;
        }
        return true;
    }

    public static boolean isCnChar(String chars) {
        StringBuilder illegalChars = new StringBuilder();
        int length = chars.length();
        for (int i = 0; i < length; i++) {
            char item = chars.charAt(i);
            if (!((item >= 0x4e00) && (item <= 0x9fbb))) {
                illegalChars.append("(").append(item).append(")");
            }
        }
        if (illegalChars.length() != 0) {
            Logger.e(TAG, "illegal char(chars): " + illegalChars.toString());
            return false;
        }
        return true;
    }

    public static boolean isEnSlot(Slot slot) {
        if (slot == null) {
            throw new IllegalArgumentException("The slot can not be null!");
        }
        List<String> wordList = slot.getWordList();
        if (wordList.isEmpty()) {
            throw new IllegalArgumentException("The slot has no word!");
        }
        for (String word : wordList) {
            boolean en = isEnChar(word);
            if (!en) {
                return false;
            }
        }
        return true;
    }

    public static boolean isCnSlot(Slot slot) {
        if (slot == null) {
            throw new IllegalArgumentException("The slot can not be null");
        }
        List<String> wordList = slot.getWordList();
        if (wordList.isEmpty()) {
            throw new IllegalArgumentException("The slot has no word");
        }
        for (String word : wordList) {
            boolean en = isCnChar(word);
            if (!en) {
                return false;
            }
        }
        return true;
    }
}
